@@ -13,7 +13,7 @@ use Perinci::Object;
 use Perinci::ToUtil;
 use Scalar::Util qw(reftype blessed);
 
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 our $REQ_VERSION = 0; # version requested by user
 
@@ -1228,6 +1228,64 @@ sub help_section_examples {
     }
 }
 
+sub help_section_result {
+    my ($self, %opts) = @_;
+
+    my $meta   = $self->{_help_meta};
+    my $rmeta  = $meta->{result};
+    my $rmetao = rimeta($rmeta);
+    my $text;
+
+    my $summary = $rmetao->langprop('summary') // '';
+    my $desc    = $rmetao->langprop('description') // '';
+    $text = $summary . ($summary ? "\n\n" : "") . $desc;
+
+    # collect handler
+    my %handler_args;
+    my %handler_metas;
+    for my $k0 (keys %$rmeta) {
+        my $v = $rmeta->{$k0};
+
+        my $k = $k0; $k =~ s/\..+//;
+        next if $k =~ /\A_/;
+
+        # check builtin result spec key
+        next if $k =~ /\A(
+                           summary|description|tags|default_lang|
+                           schema|
+                           x
+                       )\z/x;
+
+        # try a property module first
+        require "Perinci/Sub/Property/result/$k.pm";
+        my $meth = "help_hookmeta_result__$k";
+        unless ($self->can($meth)) {
+            die "No help handler for property result/$k0 ($meth)";
+        }
+        my $hm = $self->$meth;
+        my $ha = {
+            prio=>$hm->{prio}, value=>$v->{$k0}, property=>$k0,
+            meth=>"help_hook_result__$k",
+        };
+        $handler_args{$k} = $ha;
+        $handler_metas{$k} = $hm;
+    }
+
+    # call all the handlers in order
+    for my $k (sort {$handler_args{$a}{prio} <=> $handler_args{$b}{prio}}
+                   keys %handler_args) {
+        my $ha = $handler_args{$k};
+        my $meth = $ha->{meth};
+        my $t = $self->$meth(meta => $meta, %$ha);
+        $text .= $t if $t;
+    }
+
+    return unless length $text;
+
+    $self->_help_add_heading(__("Result"));
+    $self->_help_add_row([$text], {wrap=>1, indent=>1});
+}
+
 sub help_section_links {
     # not yet
 }
@@ -1262,6 +1320,7 @@ sub run_help {
             'examples',
             'description',
             'options',
+            'result',
             'links',
             'hints',
         );
@@ -1823,7 +1882,7 @@ Perinci::CmdLine - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
